==> linuxconf-1.19.src.tar.gz: linuxconf-1.19/modules/uucp/uucp.pm <==
/* _dict.cc 14/08/96 16.14.22 */
/* devices.cc 25/04/98 14.09.58 */
PUBLIC DEVICE::DEVICE (void);
PUBLIC DEVICE::DEVICE (const char *buf,
	 const SSTRING&_comments,
	 char *err);
PUBLIC void DEVICE::write (FILE *fout);
PUBLIC int DEVICE::edit (const DIALERS&dial);
PUBLIC DEVICES::DEVICES (void);
PUBLIC DEVICE *DEVICES::getitem (int no);
PROTECTED CONFIG_OBJ *DEVICES::newobj (const char *buf,
	 const SSTRING&_comments,
	 char *err);
PUBLIC void DEVICES::sort (void);
PUBLIC int DEVICES::edit (void);
/* dialers.cc 01/11/97 00.45.40 */
PUBLIC DIALER::DIALER (void);
PUBLIC DIALER::DIALER (const char *buf,
	 const SSTRING&_comments,
	 char *err);
PUBLIC void DIALER::write (FILE *fout);
PUBLIC DIALERS::DIALERS (void);
PUBLIC DIALER *DIALERS::getitem (int no)const;
PUBLIC DIALER *DIALERS::getitem (const char *type)const;
PROTECTED CONFIG_OBJ *DIALERS::newobj (const char *buf,
	 const SSTRING&_comments,
	 char *err);
/* helpf.cc 14/08/96 16.14.50 */
PUBLIC UUCP_HELP_FILE::UUCP_HELP_FILE (const char *fname);
/* internal.cc 01/11/97 00.47.40 */
PUBLIC CONFIG_OBJS::CONFIG_OBJS (CONFIG_FILE&_f);
PUBLIC int CONFIG_OBJS::read (void);
PRIVATE CONFIG_OBJ *CONFIG_OBJS::getitem (int no);
PUBLIC int CONFIG_OBJS::write (void);
/* permissions.cc 01/11/97 00.45.00 */
PUBLIC PERMISSION::PERMISSION (void);
PUBLIC PERMISSION::PERMISSION (const PERMISSION *p);
PUBLIC PERMISSION::PERMISSION (const char *buf,
	 const SSTRING&_comments,
	 char *err);
PUBLIC void PERMISSION::write (FILE *fout);
PUBLIC PERMISSION *PERMISSIONS::getitem (int no);
PUBLIC PERMISSION *PERMISSIONS::getitem (const char *machine,
	 int &no);
PUBLIC PERMISSION *PERMISSIONS::getitem (const char *machine);
PUBLIC PERMISSIONS::PERMISSIONS (void);
PROTECTED CONFIG_OBJ *PERMISSIONS::newobj (const char *buf,
	 const SSTRING&_comments,
	 char *err);
PUBLIC void PERMISSIONS::delsystem (const char *system);
/* poll.cc 01/11/97 00.45.06 */
PUBLIC POLL::POLL (const char *_system);
PUBLIC POLL::POLL (const POLL *p);
PUBLIC POLL::POLL (const char *buf,
	 const SSTRING&_comments,
	 char *err);
PUBLIC void POLL::write (FILE *fout);
PUBLIC POLLS::POLLS (void);
PUBLIC POLL *POLLS::getitem (int no);
PUBLIC POLL *POLLS::getitem (const char *system);
PUBLIC void POLLS::delsystem (const char *system);
PROTECTED CONFIG_OBJ *POLLS::newobj (const char *buf,
	 const SSTRING&_comments,
	 char *err);
/* system.cc 05/01/98 23.45.08 */
PUBLIC SYSTEM::SYSTEM (void);
PUBLIC SYSTEM::SYSTEM (const char *line,
	 const SSTRING&_comment,
	 char *err);
PUBLIC void SYSTEM::write (FILE *fout);
PUBLIC int SYSTEM::edit (PERMISSIONS&perms, POLLS&polls);
PUBLIC SYSTEM *SYSTEMS::getitem (int no);
PROTECTED CONFIG_OBJ *SYSTEMS::newobj (const char *buf,
	 const SSTRING&_comments,
	 char *err);
PUBLIC SYSTEMS::SYSTEMS (void);
PUBLIC void SYSTEMS::sort (void);
PUBLIC int SYSTEMS::edit (PERMISSIONS&perms, POLLS&polls);
/* uucp.cc 08/04/98 01.29.38 */
/* uucpmod.cc 04/03/98 17.07.02 */
PUBLIC MODULE_UUCP::MODULE_UUCP (void);
PUBLIC void MODULE_UUCP::setmenu (DIALOG&dia, MENU_CONTEXT context);
PUBLIC int MODULE_UUCP::domenu (MENU_CONTEXT context, const char *key);
PUBLIC int MODULE_UUCP::execmain (int argc, char *argv[]);

==> linuxconf-1.20.src.tar.gz: linuxconf-1.20/modules/uucp/uucp.pm <==
/* _dict.cc 14/08/1996 16.14.22 */
/* devices.cc 07/08/2000 00.49.48 */
PUBLIC DEVICE::DEVICE (void);
PUBLIC DEVICE::DEVICE (const char *buf,
	 const SSTRING&_comments,
	 char *err);
PUBLIC void DEVICE::write (FILE_CFG *fout);
PUBLIC int DEVICE::edit (const DIALERS&dial);
PUBLIC DEVICES::DEVICES (void);
PUBLIC DEVICE *DEVICES::getitem (int no);
PROTECTED CONFIG_OBJ *DEVICES::newobj (const char *buf,
	 const SSTRING&_comments,
	 char *err);
PUBLIC void DEVICES::sort (void);
PUBLIC int DEVICES::edit (void);
/* dialers.cc 07/08/2000 00.48.58 */
PUBLIC DIALER::DIALER (void);
PUBLIC DIALER::DIALER (const char *buf,
	 const SSTRING&_comments,
	 char *err);
PUBLIC void DIALER::write (FILE_CFG *fout);
PUBLIC DIALERS::DIALERS (void);
PUBLIC DIALER *DIALERS::getitem (int no)const;
PUBLIC DIALER *DIALERS::getitem (const char *type)const;
PROTECTED CONFIG_OBJ *DIALERS::newobj (const char *buf,
	 const SSTRING&_comments,
	 char *err);
/* helpf.cc 14/08/1996 16.14.50 */
PUBLIC UUCP_HELP_FILE::UUCP_HELP_FILE (const char *fname);
/* internal.cc 07/08/2000 00.47.50 */
PUBLIC CONFIG_OBJS::CONFIG_OBJS (CONFIG_FILE&_f);
PUBLIC int CONFIG_OBJS::read (void);
PRIVATE CONFIG_OBJ *CONFIG_OBJS::getitem (int no);
PUBLIC int CONFIG_OBJS::write (void);
/* permissions.cc 07/08/2000 00.51.28 */
PUBLIC PERMISSION::PERMISSION (void);
PUBLIC PERMISSION::PERMISSION (const PERMISSION *p);
PUBLIC PERMISSION::PERMISSION (const char *buf,
	 const SSTRING&_comments,
	 char *err);
PUBLIC void PERMISSION::write (FILE_CFG *fout);
PUBLIC PERMISSION *PERMISSIONS::getitem (int no);
PUBLIC PERMISSION *PERMISSIONS::getitem (const char *machine,
	 int &no);
PUBLIC PERMISSION *PERMISSIONS::getitem (const char *machine);
PUBLIC PERMISSIONS::PERMISSIONS (void);
PROTECTED CONFIG_OBJ *PERMISSIONS::newobj (const char *buf,
	 const SSTRING&_comments,
	 char *err);
PUBLIC void PERMISSIONS::delsystem (const char *system);
/* poll.cc 07/08/2000 00.51.58 */
PUBLIC POLL::POLL (const char *_system);
PUBLIC POLL::POLL (const POLL *p);
PUBLIC POLL::POLL (const char *buf,
	 const SSTRING&_comments,
	 char *err);
PUBLIC void POLL::write (FILE_CFG *fout);
PUBLIC POLLS::POLLS (void);
PUBLIC POLL *POLLS::getitem (int no);
PUBLIC POLL *POLLS::getitem (const char *system);
PUBLIC void POLLS::delsystem (const char *system);
PROTECTED CONFIG_OBJ *POLLS::newobj (const char *buf,
	 const SSTRING&_comments,
	 char *err);
/* system.cc 07/08/2000 00.49.24 */
PUBLIC SYSTEM::SYSTEM (void);
PUBLIC SYSTEM::SYSTEM (const char *line,
	 const SSTRING&_comment,
	 char *err);
PUBLIC void SYSTEM::write (FILE_CFG *fout);
PUBLIC int SYSTEM::edit (PERMISSIONS&perms, POLLS&polls);
PUBLIC SYSTEM *SYSTEMS::getitem (int no);
PROTECTED CONFIG_OBJ *SYSTEMS::newobj (const char *buf,
	 const SSTRING&_comments,
	 char *err);
PUBLIC SYSTEMS::SYSTEMS (void);
PUBLIC void SYSTEMS::sort (void);
PUBLIC int SYSTEMS::edit (PERMISSIONS&perms, POLLS&polls);
/* uucp.cc 04/08/2000 13.07.00 */
/* uucpmod.cc 06/01/1999 23.14.38 */
PUBLIC MODULE_UUCP::MODULE_UUCP (void);
PUBLIC void MODULE_UUCP::setmenu (DIALOG&dia, MENU_CONTEXT context);
PUBLIC int MODULE_UUCP::domenu (MENU_CONTEXT context, const char *key);
PUBLIC int MODULE_UUCP::execmain (int argc, char *argv[]);
